==> haskell-skylighting-0.10.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting
version:              0.10.2
visibility:           public
id:                   skylighting-0.10.2-16XwQwd69hkIuD9fZB0SgD
key:                  skylighting-0.10.2-16XwQwd69hkIuD9fZB0SgD
license:              GPL-2.0-only
copyright:            (C) 2016 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  0a23d1b92f55734de067b24454a99461
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Cs Skylighting.Syntax.Css
    Skylighting.Syntax.Curry Skylighting.Syntax.D
    Skylighting.Syntax.Default Skylighting.Syntax.Diff
    Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
    Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
    Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
    Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
    Skylighting.Syntax.Elm Skylighting.Syntax.Email
    Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
    Skylighting.Syntax.FortranFixed Skylighting.Syntax.FortranFree
    Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
    Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
    Skylighting.Syntax.Go Skylighting.Syntax.Graphql
    Skylighting.Syntax.Groovy Skylighting.Syntax.Hamlet
    Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
    Skylighting.Syntax.Html Skylighting.Syntax.Idris
    Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
    Skylighting.Syntax.J Skylighting.Syntax.Java
    Skylighting.Syntax.Javadoc Skylighting.Syntax.JavascriptReact
    Skylighting.Syntax.Javascript Skylighting.Syntax.Json
    Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
    Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
    Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
    Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
    Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
    Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
    Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
    Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
    Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
    Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
    Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
    Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
    Skylighting.Syntax.Mustache Skylighting.Syntax.Nasm
    Skylighting.Syntax.Nim Skylighting.Syntax.Noweb
    Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
    Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
    Skylighting.Syntax.Opencl Skylighting.Syntax.Pascal
    Skylighting.Syntax.Perl Skylighting.Syntax.Php
    Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
    Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
    Skylighting.Syntax.Prolog Skylighting.Syntax.Protobuf
    Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
    Skylighting.Syntax.Python Skylighting.Syntax.Qml
    Skylighting.Syntax.R Skylighting.Syntax.Relaxng
    Skylighting.Syntax.Relaxngcompact Skylighting.Syntax.Rest
    Skylighting.Syntax.Rhtml Skylighting.Syntax.Roff
    Skylighting.Syntax.Ruby Skylighting.Syntax.Rust
    Skylighting.Syntax.Scala Skylighting.Syntax.Scheme
    Skylighting.Syntax.Sci Skylighting.Syntax.Sed
    Skylighting.Syntax.Sgml Skylighting.Syntax.Sml
    Skylighting.Syntax.SpdxComments Skylighting.Syntax.SqlMysql
    Skylighting.Syntax.SqlPostgresql Skylighting.Syntax.Sql
    Skylighting.Syntax.Stata Skylighting.Syntax.Tcl
    Skylighting.Syntax.Tcsh Skylighting.Syntax.Texinfo
    Skylighting.Syntax.Toml Skylighting.Syntax.Typescript
    Skylighting.Syntax.Verilog Skylighting.Syntax.Vhdl
    Skylighting.Syntax.Xml Skylighting.Syntax.Xorg
    Skylighting.Syntax.Xslt Skylighting.Syntax.Xul
    Skylighting.Syntax.Yacc Skylighting.Syntax.Yaml
    Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-8.10.4/site-local/skylighting-0.10.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/skylighting-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/skylighting-0.10.2
hs-libraries:         HSskylighting-0.10.2-16XwQwd69hkIuD9fZB0SgD
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.12.0
    containers-0.6.2.1 skylighting-core-0.10.2-HSEw3drgWWzAjU02raD3kz

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.10.5.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting
version:              0.10.5.1
visibility:           public
id:                   skylighting-0.10.5.1-I3gBS1jWZTPIrtiUFKrFd6
key:                  skylighting-0.10.5.1-I3gBS1jWZTPIrtiUFKrFd6
license:              GPL-2.0-only
copyright:            (C) 2016 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides generated syntax modules
    based on the KDE XML definitions provided by the
    @skylighting-core@ package. As a result this
    package is licensed under the GPL.

category:             Text
abi:                  44e9f263ed12e0f033440eec5482037e
exposed:              True
exposed-modules:
    Skylighting,
    Skylighting.Core from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Core,
    Skylighting.Format.ANSI from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Format.ANSI,
    Skylighting.Format.HTML from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Format.HTML,
    Skylighting.Format.LaTeX from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Format.LaTeX,
    Skylighting.Parser from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Parser,
    Skylighting.Regex from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Regex,
    Skylighting.Styles from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Styles,
    Skylighting.Syntax,
    Skylighting.Tokenizer from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Tokenizer,
    Skylighting.Types from skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb:Skylighting.Types

hidden-modules:
    Skylighting.Syntax.Abc Skylighting.Syntax.Actionscript
    Skylighting.Syntax.Ada Skylighting.Syntax.Agda
    Skylighting.Syntax.Alert Skylighting.Syntax.Apache
    Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
    Skylighting.Syntax.Ats Skylighting.Syntax.Awk
    Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
    Skylighting.Syntax.Boo Skylighting.Syntax.C
    Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
    Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
    Skylighting.Syntax.Coldfusion Skylighting.Syntax.Comments
    Skylighting.Syntax.Commonlisp Skylighting.Syntax.Cpp
    Skylighting.Syntax.Cs Skylighting.Syntax.Css
    Skylighting.Syntax.Curry Skylighting.Syntax.D
    Skylighting.Syntax.Default Skylighting.Syntax.Diff
    Skylighting.Syntax.Djangotemplate Skylighting.Syntax.Dockerfile
    Skylighting.Syntax.Dot Skylighting.Syntax.Doxygen
    Skylighting.Syntax.Doxygenlua Skylighting.Syntax.Dtd
    Skylighting.Syntax.Eiffel Skylighting.Syntax.Elixir
    Skylighting.Syntax.Elm Skylighting.Syntax.Email
    Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
    Skylighting.Syntax.FortranFixed Skylighting.Syntax.FortranFree
    Skylighting.Syntax.Fsharp Skylighting.Syntax.Gcc
    Skylighting.Syntax.Glsl Skylighting.Syntax.Gnuassembler
    Skylighting.Syntax.Go Skylighting.Syntax.Graphql
    Skylighting.Syntax.Groovy Skylighting.Syntax.Hamlet
    Skylighting.Syntax.Haskell Skylighting.Syntax.Haxe
    Skylighting.Syntax.Html Skylighting.Syntax.Idris
    Skylighting.Syntax.Ini Skylighting.Syntax.Isocpp
    Skylighting.Syntax.J Skylighting.Syntax.Java
    Skylighting.Syntax.Javadoc Skylighting.Syntax.JavascriptReact
    Skylighting.Syntax.Javascript Skylighting.Syntax.Json
    Skylighting.Syntax.Jsp Skylighting.Syntax.Julia
    Skylighting.Syntax.Kotlin Skylighting.Syntax.Latex
    Skylighting.Syntax.Lex Skylighting.Syntax.Lilypond
    Skylighting.Syntax.LiterateCurry Skylighting.Syntax.LiterateHaskell
    Skylighting.Syntax.Llvm Skylighting.Syntax.Lua
    Skylighting.Syntax.M4 Skylighting.Syntax.Makefile
    Skylighting.Syntax.Mandoc Skylighting.Syntax.Markdown
    Skylighting.Syntax.Mathematica Skylighting.Syntax.Matlab
    Skylighting.Syntax.Maxima Skylighting.Syntax.Mediawiki
    Skylighting.Syntax.Metafont Skylighting.Syntax.Mips
    Skylighting.Syntax.Modelines Skylighting.Syntax.Modula2
    Skylighting.Syntax.Modula3 Skylighting.Syntax.Monobasic
    Skylighting.Syntax.Mustache Skylighting.Syntax.Nasm
    Skylighting.Syntax.Nim Skylighting.Syntax.Noweb
    Skylighting.Syntax.Objectivec Skylighting.Syntax.Objectivecpp
    Skylighting.Syntax.Ocaml Skylighting.Syntax.Octave
    Skylighting.Syntax.Opencl Skylighting.Syntax.Pascal
    Skylighting.Syntax.Perl Skylighting.Syntax.Php
    Skylighting.Syntax.Pike Skylighting.Syntax.Postscript
    Skylighting.Syntax.Povray Skylighting.Syntax.Powershell
    Skylighting.Syntax.Prolog Skylighting.Syntax.Protobuf
    Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
    Skylighting.Syntax.Python Skylighting.Syntax.Qml
    Skylighting.Syntax.R Skylighting.Syntax.Raku
    Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
    Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
    Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
    Skylighting.Syntax.Rust Skylighting.Syntax.Scala
    Skylighting.Syntax.Scheme Skylighting.Syntax.Sci
    Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
    Skylighting.Syntax.Sml Skylighting.Syntax.SpdxComments
    Skylighting.Syntax.SqlMysql Skylighting.Syntax.SqlPostgresql
    Skylighting.Syntax.Sql Skylighting.Syntax.Stata
    Skylighting.Syntax.Tcl Skylighting.Syntax.Tcsh
    Skylighting.Syntax.Texinfo Skylighting.Syntax.Toml
    Skylighting.Syntax.Typescript Skylighting.Syntax.Verilog
    Skylighting.Syntax.Vhdl Skylighting.Syntax.Xml
    Skylighting.Syntax.Xorg Skylighting.Syntax.Xslt
    Skylighting.Syntax.Xul Skylighting.Syntax.Yacc
    Skylighting.Syntax.Yaml Skylighting.Syntax.Zsh

import-dirs:          /usr/lib/ghc-8.10.4/site-local/skylighting-0.10.5.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/skylighting-0.10.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/skylighting-0.10.5.1
hs-libraries:         HSskylighting-0.10.5.1-I3gBS1jWZTPIrtiUFKrFd6
depends:
    base-4.14.1.0 binary-0.8.8.0 containers-0.6.2.1
    skylighting-core-0.10.5.1-Bc3x8g2oj6bJiKFo2mkOAb

haddock-interfaces:   /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html:         /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
